@@ -1,5 +1,5 @@
 URL = "https://%s"
-DEFAULT_DOMAIN = "qa.datomize.com"
+DEFAULT_DOMAIN = "app.datomize.com"
 
 MANAGEMENT = "/api"
 ONBOARDING = "/onboarding"
